@@ -32,6 +32,10 @@ class FTPHook(BaseHook):
     Errors that may occur throughout but should be handled downstream.
     You can specify mode for data transfers in the extra field of your
     connection as ``{"passive": "true"}``.
+
+    :param ftp_conn_id: The :ref:`ftp connection id <howto/connection:ftp>`
+        reference.
+    :type ftp_conn_id: str
     """
 
     conn_name_attr = 'ftp_conn_id'
@@ -170,6 +174,7 @@ class FTPHook(BaseHook):
         # file-like buffer
         if not callback:
             if is_path:
+                # pylint: disable=consider-using-with
                 output_handle = open(local_full_path_or_buffer, 'wb')
             else:
                 output_handle = local_full_path_or_buffer
@@ -205,6 +210,7 @@ class FTPHook(BaseHook):
         is_path = isinstance(local_full_path_or_buffer, str)
 
         if is_path:
+            # pylint: disable=consider-using-with
             input_handle = open(local_full_path_or_buffer, 'rb')
         else:
             input_handle = local_full_path_or_buffer
