@@ -32,7 +32,8 @@ class FTPSensor(BaseSensorOperator):
     :param fail_on_transient_errors: Fail on all errors,
         including 4xx transient errors. Default True.
     :type fail_on_transient_errors: bool
-    :param ftp_conn_id: The connection to run the sensor against
+    :param ftp_conn_id: The :ref:`ftp connection id <howto/connection:ftp>`
+        reference to run the sensor against.
     :type ftp_conn_id: str
     """
 
@@ -70,7 +71,9 @@ class FTPSensor(BaseSensorOperator):
         with self._create_hook() as hook:
             self.log.info('Poking for %s', self.path)
             try:
-                hook.get_mod_time(self.path)
+                mod_time = hook.get_mod_time(self.path)
+                self.log.info('Found File %s last modified: %s', str(self.path), str(mod_time))
+
             except ftplib.error_perm as e:
                 self.log.error('Ftp error encountered: %s', str(e))
                 error_code = self._get_error_code(e)
